/*
License: GPLv2, read more from COPYING

This file contains the functionality of help menu.
 */
#include <tangle.h>
#include <string.h>
#include "communitymenu.h"
#include "startmenu.h"
#include "../jammo.h"
#include "help.h"

static ClutterContainer *questionlist = 0;
static gint listItemHeight = 0;

void start_helpdesk()
{
	puts("Starting Help\n");

	int numberOfLoops = 8;

	clutter_actor_hide(jammo_get_actor_by_id("communitymenu-view"));

	ClutterActor* mainview;
	mainview = jammo_get_actor_by_id("main-views-widget");

	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
	
	ClutterActor* help_view = jammo_get_actor_by_id("help-view");

	if(help_view)
	{
		clutter_actor_show(CLUTTER_ACTOR(help_view));

		if(numberOfLoops > 5)
			questionlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-songs-list-scrollable"));	

		else
			questionlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-songs-list-unscrollable"));	

		clutter_actor_lower(jammo_get_actor_by_id("helpdesk_right-index"),jammo_get_actor_by_id("helpdesk_down-index"));
		clutter_actor_lower(CLUTTER_ACTOR(questionlist),jammo_get_actor_by_id("helpdesk_down-index"));

		for(int i = 0; i < numberOfLoops; i++)
			helpdesk_add_loop_to_list(NULL, i);	

		ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(questionlist), TANGLE_TYPE_SCROLL_ACTION);
	
		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(helpdesk_autoscroll_to_correct_pos), questionlist);


	}

	else 	puts("can't find 'help-view' ");
}

void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
{
	helpdesk_clear_container(questionlist);
	start_communitymenu();
}

void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none)
{
	helpdesk_clear_container(questionlist);
	startmenu_goto_startmenu(tanglebutton, none);
}

void helpdesk_get_questions()
{
	//TODO: Create code for fetching helpdesk questions from remote server
	puts("Fetching questions\n");
	
}

void helpdesk_ask_question()
{
	puts("Asking Question\n");

}

void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll)
{
	gint slot;
	gfloat not_used, offset;

	ClutterAction *action = tangle_actor_get_action_by_type(listToScroll, TANGLE_TYPE_SCROLL_ACTION);
	
	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(action), &not_used, &offset);

	slot = (gint)offset % (gint)listItemHeight < listItemHeight / 2 ? (gint)(offset) / listItemHeight  
							  		: (gint)(offset) / listItemHeight + 1;

	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*listItemHeight), NULL);
}


gboolean helpdesk_add_loop_to_list(char* loopName, int numberOfLoops)
{
	ClutterActor *avatarImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL);
	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);

	ClutterActor *text = clutter_text_new_with_text("Courier 20", "Kysymys Tähän.");	

	ClutterActor *mentorButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
					"/opt/jammo/communitymenu/community_mentor_icon.png", NULL));
	ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
					"/opt/jammo/communitymenu/community_comment_icon.png", NULL));

	ClutterContainer *listContainer = clutter_group_new();

	if(avatarImage == NULL || colorbar == NULL)
		return FALSE;	

	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(avatarImage);

	clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
	clutter_container_add_actor(listContainer, avatarImage);
	
	clutter_actor_set_position(text, 60, 23);			
	clutter_container_add_actor(listContainer, text);
	
	clutter_actor_set_position(commentButton, 690, 15);
	clutter_container_add_actor(listContainer, commentButton);

	g_signal_connect_swapped(CLUTTER_ACTOR(mentorButton), "clicked", G_CALLBACK(helpdesk_view_mentor_topic), 
						clutter_actor_get_parent(mentorButton));

	g_signal_connect_swapped(CLUTTER_ACTOR(commentButton), "clicked", G_CALLBACK(helpdesk_comment), 
						clutter_actor_get_parent(commentButton));

	clutter_container_add_actor(questionlist, CLUTTER_ACTOR(listContainer));

	if(numberOfLoops <= 6)
		clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * numberOfLoops);	

	else
		clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * 6);		

	return TRUE;
}


void helpdesk_comment(ClutterActor *actor)
{
	GList *children = clutter_container_get_children(questionlist); //Get list of actors
	GList *node = children;

	int index = 0;
	int found = 0;
	
	while(node != NULL)
	{
		index++;

		if(actor == node->data)
		{
			printf("Found it. Index %d\n", index);
			found = 1;
			break;
		}

		node = node->next;
	}

	g_list_free(children);
}

void helpdesk_view_mentor_topic(ClutterActor *actor)
{

}

void helpdesk_clear_container(ClutterContainer *listToClear)
{
	int i = 0;

	if(listToClear != NULL)
	{
	 	
		GList *listItems;
		listItems = clutter_container_get_children(listToClear);
	
		if(listItems != NULL)
		{
			do
			{
				if(i > 0)
					listItems = listItems->next;
				
				clutter_container_remove_actor(CLUTTER_CONTAINER(listToClear), CLUTTER_ACTOR(listItems->data));
				i++;
	
			}while(listItems->next != NULL);
	
			g_list_free(listItems);
		}
	}
}
